<template>
  <div class="mobile-container">
    <van-sticky>
      <navBar @clickLeft="onClickLeft" :title="title"></navBar>
    </van-sticky>
    <div class="cell-group">
      <van-cell-group inset class="device-group">
        <div class="device-cell">
          <div class="device-name">
            <!-- <van-icon name="label" color="#1989fa" /> -->
            {{ deviceData.name }}
          </div>
          <div class="device-status">
            <van-tag type="success" v-if="deviceData.status == 1">正常
            </van-tag>
            <van-tag type="warning" v-if="deviceData.status == 2">故障
            </van-tag>
            <van-tag type="danger" v-if="deviceData.status == 3">报警
            </van-tag>
          </div>
        </div>
        <div class="device-content">
          <p>
            <span style="color: #333">所属区域：</span>{{ deviceData.areaName }}
          </p>
          <p>
            <span style="color: #333">产品名称：</span>{{ deviceData.productName }}
          </p>
          <p>
            <span style="color: #333">产品分类：</span>{{ deviceData.address }}
          </p>
          <p>
            <span style="color: #333">安装详细地址：</span>{{ deviceData.address }}
          </p>
        </div>
      </van-cell-group>
    </div>

    <van-pull-refresh class="van-hairline--top" v-model="refreshing" @refresh="onRefresh">
      <van-list v-if="!refreshing" v-model="loading" :finished="finished" finished-text="没有更多了" @load="onLoad">
        <div class="device-father">
          <div v-for="(device, index) in realtimeData" :key="index" class="device van-hairline--bottom"
            @click="handleDetail(device)">
            <div class="device-item">
              <div class="device-item-text">
                <div class="device-item-content" style="margin-bottom: 6px">
                  <div>
                    <div class="device-name">
                      {{ device.warnName }}
                    </div>
                  </div>
                  <div class="device-statuss" :style="device.handleStatus == '待调度'
                    ? { backgroundColor: '#E6A23C' }
                    : device.handleStatus ==
                      '处置完成'
                      ? { backgroundColor: '#13ce66' }
                      : device.handleStatus ==
                        '待处理'
                        ? { backgroundColor: '#ff4949' }
                        : device.handleStatus ==
                          '正在处置'
                          ? { backgroundColor: '#409EFF' }
                          : device.handleStatus ==
                            '已归档'
                            ? { backgroundColor: '#191970' }
                            : device.handleStatus ==
                              '已评估'
                              ? { backgroundColor: '#8a2be2' }
                              : { backgroundColor: '#a9a9a9' }
                    ">
                    {{ device.handleStatus }}
                  </div>
                </div>
              </div>
              <div class="device-content">
                <p>告警时间：{{ device.warnTime }}</p>
                <p>告警缘由：{{ device.warnReason }}</p>
                <p>处理结果：{{ device.handleResult }}</p>
              </div>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>
    <!-- <van-empty description="该设备暂无告警数据" v-else /> -->
  </div>
</template>

<script>
import dictUtils from '@/components/dict/DictSelectUtils.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import req from '@/request.js'
import navBar from '../components/navBar.vue'

export default {
  name: 'RealtimeData',
  components: {
    navBar
  },
  data() {
    return {
      value: '',
      handleStatusList: [],
      finished: false,
      title: '告警数据',
      protal: window.context.portal,
      deviceId: '',
      deviceData: {},
      queryParam: {
        pageBean: {
          page: 0,
          pageSize: 20,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'warn.DEVICE_CODE_',
            relation: 'AND',
            value: this.$route.query.item.code
          }
        ],
        sorter: [
          {
            direction: 'DESC',
            property: 'createTime'
          }
        ]
      },
      loading: false,
      type: '',
      realtimeData: [],
      // hazard: [
      //   // 危险源监测
      //   {
      //     value: '',
      //     name: '采集时间'
      //   },
      //   {
      //     value: '',
      //     name: '气体浓度'
      //   }
      // ],
      // barricade: [
      //   // 升降路障
      //   {
      //     value: '',
      //     name: '操作人'
      //   },
      //   {
      //     value: '',
      //     name: '动作标识'
      //   },
      //   {
      //     value: '',
      //     name: '动作状态'
      //   }
      // ],
      // water: [
      //   // 低洼积水监测
      //   {
      //     value: '',
      //     name: '采集时间'
      //   },
      //   {
      //     value: '',
      //     name: '水位高度'
      //   }
      // ],
      // signboaerd: [
      //   // 标志牌监测
      //   {
      //     value: '',
      //     name: '电池电量',
      //     unit: '%'
      //   },
      //   {
      //     value: '',
      //     name: '数据类型'
      //   },
      //   {
      //     value: '',
      //     name: 'X轴角度',
      //     unit: '°'
      //   },
      //   {
      //     value: '',
      //     name: 'Y轴角度',
      //     unit: '°'
      //   },
      //   {
      //     value: '',
      //     name: 'Z轴角度',
      //     unit: '°'
      //   },
      //   {
      //     value: '',
      //     name: '设备电压',
      //     unit: 'v'
      //   }
      // ],
      dataTypeList: [],
      actionList: [],
      statusList: [],
      hasData: true,
      refreshing: false
    }
  },
  created() {
    this.handleStatusList = dictUtils.getDictItemsFromCache('clzt')
    this.handleStatusList = this.handleStatusList.map((item) => {
      return { text: item.name, value: item.value }
    })
  },
  mounted() {
    this.dataTypeList = dictUtils.getDictItemsFromCache('sjlx')
    this.actionList = dictUtils.getDictItemsFromCache('dzbs')
    this.statusList = dictUtils.getDictItemsFromCache('cgzt')
    this.deviceId = this.$route.query.item
    // this.getRealtimeData()
    this.getDevice(this.deviceId.id)
  },
  methods: {
    onRefresh() {
      setTimeout(() => {
        this.queryParam.pageBean.page = 1
        this.refreshing = true
        this.realtimeData = []
        this.getRealtimeData()
      }, 500)
    },
    onLoad() {
      setTimeout(() => {
        this.queryParam.pageBean.page += 1
        if (!this.finished) {
          this.getRealtimeData()
        }
        this.loading = false;
      }, 500);
    },
    onClickLeft() {
      this.$router.go(-1)
    },
    getDevice(id) {
      equipmentManage.deviceDetailsInfo(id, (res) => {
        this.deviceData = res // 设备详情
        console.log(this.deviceData, '设备详情')
      })
    },
    getRealtimeData() {
      // this.finished = false
      let params = {
        url: `${this.protal}/device/warnInfo/query`,
        data: this.queryParam,
        method: 'post'
      }
      req.request(params).then((res) => {
        if (res.data.rows.length < this.queryParam.pageBean.pageSize) {
          this.finished = true
        }
        if (res.data.rows.length != 0) {
          // this.finished = true
          res.data.rows.forEach((item) => {
            this.handleStatusList.forEach((val) => {
              if (item.handleStatus == val.value) {
                item['handleStatus'] = val.text
              }
            })
          })
          this.realtimeData = [...this.realtimeData, ...res.data.rows]
          // this.type = res.data.value.productType
          // this.formatData()
        } else {
          // this.hasData = false
          // this.finished = true
        }
        this.refreshing = false
      })
    }
    // formatData() {
    //   if (this.type == 'hazard') {
    //     for (let key in this.realtimeData) {
    //       if (key == 'collTime') {
    //         this.hazard[0].value = this.realtimeData[key]
    //       } else if (key == 'sdata') {
    //         this.hazard[1].value = this.realtimeData[key]
    //       }
    //     }
    //     this.realtimeData = this.hazard
    //   } else if (this.type == 'barricade') {
    //     for (let key in this.realtimeData) {
    //       if (key == 'createBy') {
    //         this.barricade[0].value = this.realtimeData[key]
    //       } else if (key == 'action') {
    //         this.actionList.forEach(type => {
    //           if (this.realtimeData[key] == type.value) {
    //             this.barricade[1].value = type.name
    //           }
    //         })
    //       } else if (key == 'status') {
    //         this.statusList.forEach(type => {
    //           if (this.realtimeData[key] == type.value) {
    //             this.barricade[2].value = type.name
    //           }
    //         })
    //       }
    //     }
    //     this.realtimeData = this.barricade
    //   } else if (this.type == 'water') {
    //     for (let key in this.realtimeData) {
    //       if (key == 'collTime') {
    //         this.water[0].value = this.realtimeData[key]
    //       } else if (key == 'sdata') {
    //         this.water[1].value = this.realtimeData[key]
    //       }
    //     }
    //     this.realtimeData = this.water
    //   } else if (this.type == 'signboaerd') {
    //     for (let key in this.realtimeData) {
    //       if (key == 'batteryValue') {
    //         this.signboaerd[0].value = this.realtimeData[key]
    //       } else if (key == 'dataType') {
    //         this.dataTypeList.forEach(type => {
    //           if (this.realtimeData[key] == type.value) {
    //             this.signboaerd[1].value = type.name
    //           }
    //         })
    //       } else if (key == 'angleX') {
    //         this.signboaerd[2].value = this.realtimeData[key]
    //       } else if (key == 'angleY') {
    //         this.signboaerd[3].value = this.realtimeData[key]
    //       } else if (key == 'angleZ') {
    //         this.signboaerd[4].value = this.realtimeData[key]
    //       } else if (key == 'batteryVoltage') {
    //         this.signboaerd[5].value = this.realtimeData[key]
    //       }
    //     }
    //     this.realtimeData = this.signboaerd
    //   }
    // }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.mobile-container {
  position: fixed;
  top: 0;
  z-index: 100;
  width: 100%;
  min-height: 100%;
  background-color: #f9f9f9;
  // background-color: $--mobile-bg;
}

.cell-group {
  padding: 50px;
}

.device-content {
  // padding: 50px 0px 50px 0px;
  height: 400px;
  font-size: 50px;

  p {
    color: #929494;
    margin: 10px 0 10px 0;
  }
}

.device-group {
  padding: 60px;
  margin-top: 16px !important;
}

.group-title {
  padding: 20px 16px 10px 16px;
}

.title-bar {
  display: inline-block;
  width: 4px;
  height: 12px;
  background-color: #1989fa;
  margin-right: 4px;
  vertical-align: middle;
}

.device-cell {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 6px 0;
}

.device-name {
  font-size: 72px;
  color: $--mobile-text-main;
}

.cell-title {
  color: $--mobile-text-sub;
  font-size: 82px;
  margin-right: 10px;
}

.margin-bottom {
  margin-bottom: 16px !important;
}

.realtime-unit {
  color: $--mobile-text-sub;
  margin-left: 10px;
  font-size: 78px;
}

.realtime-title {
  color: $--mobile-text-sub;
  margin-bottom: 6px;
  font-size: 82px;
}

.grid-container {
  margin: 16px 0;
}

::v-deep .van-cell-group--inset {
  margin: 0 0;
  border-radius: 50px;
}

::v-deep .van-pull-refresh {
  overflow: scroll;
  height: 100%;
}

.device-father {
  margin-bottom: 600px;
}

.device-status .van-tag {
    display: block;
    text-align: center;
    height: 80px;
    line-height: 80px;
    font-size: 60px;
    padding: 0 40px;
  }

.device {
  background-color: #f5f5f5;
  // margin-bottom: 6px;
  padding: 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  // display: flex;
  // align-items: center;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    height: 400px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 0px 20px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 60px;
    }
  }

  .device-name {
    font-size: 72px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-real {
    width: 140px;
    line-height: 140px;
    text-align: center;
    color: #07c160;
    border-radius: 70px;
    font-size: 10px;
    border: 1px solid #07c160;
    margin-right: 40px;
  }

  .device-alarm {
    width: 140px;
    line-height: 140px;
    text-align: center;
    color: #ee0a24;
    border-radius: 70px;
    font-size: 10px;
    border: 1px solid #ee0a24;
  }

  .device-statuss {
    width: 230px;
    border-radius: 5px;
    padding: 5px 20px;
    font-size: 50px;
    text-align: center;
    color: white;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom.scss';
</style>
